class GenerateKeysException(Exception):
    pass

class CreateAccountException(Exception):
    pass

class PushContractTransactionException(Exception):
    pass

class GetTableException(Exception):
	pass

class GetBalanceException(Exception):
    pass

class GetAccountException(Exception):
    pass